<?php

namespace Litecms\Doctorrequest\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Litecms\Doctorrequest\Interfaces\DoctorrequestRepositoryInterface;
use Litecms\Doctorrequest\Repositories\Presenter\DoctorrequestItemTransformer;

/**
 * Pubic API controller class.
 */
class DoctorrequestPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Litecms\Doctorrequest\Interfaces\DoctorrequestRepositoryInterface $doctorrequest
     *
     * @return type
     */
    public function __construct(DoctorrequestRepositoryInterface $doctorrequest)
    {
        $this->repository = $doctorrequest;
        parent::__construct();
    }

    /**
     * Show doctorrequest's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $doctorrequests = $this->repository
            ->setPresenter('\\Litecms\\Doctorrequest\\Repositories\\Presenter\\DoctorrequestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $doctorrequests['code'] = 2000;
        return response()->json($doctorrequests)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show doctorrequest.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $doctorrequest = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($doctorrequest)) {
            $doctorrequest         = $this->itemPresenter($module, new DoctorrequestItemTransformer);
            $doctorrequest['code'] = 2001;
            return response()->json($doctorrequest)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
