<?php

namespace Litecms\Doctorrequest\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Litecms\Doctorrequest\Models\Doctorrequest;

class DoctorrequestPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the doctorrequest.
     *
     * @param User $user
     * @param Doctorrequest $doctorrequest
     *
     * @return bool
     */
    public function view(User $user, Doctorrequest $doctorrequest)
    {
        if ($user->canDo('doctorrequest.doctorrequest.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $doctorrequest->user_id;
    }

    /**
     * Determine if the given user can create a doctorrequest.
     *
     * @param User $user
     * @param Doctorrequest $doctorrequest
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('doctorrequest.doctorrequest.create');
    }

    /**
     * Determine if the given user can update the given doctorrequest.
     *
     * @param User $user
     * @param Doctorrequest $doctorrequest
     *
     * @return bool
     */
    public function update(User $user, Doctorrequest $doctorrequest)
    {
        if ($user->canDo('doctorrequest.doctorrequest.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $doctorrequest->user_id;
    }

    /**
     * Determine if the given user can delete the given doctorrequest.
     *
     * @param User $user
     * @param Doctorrequest $doctorrequest
     *
     * @return bool
     */
    public function destroy(User $user, Doctorrequest $doctorrequest)
    {
        if ($user->canDo('doctorrequest.doctorrequest.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $doctorrequest->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
