<?php

namespace Litecms\Doctorrequest\Providers;

use Illuminate\Support\ServiceProvider;

class DoctorrequestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'doctorrequest');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'doctorrequest');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('doctorrequest', function ($app) {
            return $this->app->make('Litecms\Doctorrequest\Doctorrequest');
        });

        // Bind Doctorrequest to repository
        $this->app->bind(
            \Litecms\Doctorrequest\Interfaces\DoctorrequestRepositoryInterface::class,
            \Litecms\Doctorrequest\Repositories\Eloquent\DoctorrequestRepository::class
        );

        $this->app->register(\Litecms\Doctorrequest\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Doctorrequest\Providers\EventServiceProvider::class);
        $this->app->register(\Litecms\Doctorrequest\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['doctorrequest'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/doctorrequest.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/doctorrequest')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/doctorrequest')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
